@@ -135,7 +135,7 @@ def thingiverse_deploy_files(access_path, files, whitelist, thingdata, headers):
                               "http://api.thingiverse.com/things/"
                                 + str(thingdata["thingiverse_id"])
                                 + access_path + "/"
-                                + str(file["thingiverse_id"]),
+                                + str(file["id"]),
                                 headers=headers).text)
 
         #print(json.dumps(deletion_response, indent=4))
@@ -475,6 +475,8 @@ def deploy_thingiverse(api_token, thingdata, project_path, modelfiles, imgfiles)
     ##########################################################################
     ##                     Thingiverse deployment                           ##
     ##########################################################################
+    ########## Thing data
+    datapath = project_path + "/thingdata.json"
     
     headers = {"Authorization": "Bearer " + api_token}
     
@@ -499,7 +501,7 @@ def deploy_thingiverse(api_token, thingdata, project_path, modelfiles, imgfiles)
             mode = "patch"
             print("Thing already exists, running in patch mode")
         else:
-            print("""Thing ID specified in flags.json does not belong to 
+            print("""Thing ID specified in thingdata.json does not belong to 
                         creator, exiting""")
             sys.exit(os.EX_NOPERM)
 
@@ -742,4 +744,4 @@ def main():
 ##                        main() idiom                                  ##
 ##########################################################################
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
